# threed_strudel
threed_strudel is a set of tools for cryo-EM maps data mining and motif based map-model validation. 
# Requirements
biopython, mrcfile, mpi4py, psutil, scipy, ChimeraX
# Instalation
    pip install threed-strudel

# Set ChimeraX path
    strudel_setChimeraX.py path_to_chimeraX_executable 
    
# Usage
Chop an atomic model and the corresponding EM map into amino acid residues:

    strudel_chopModelMapMPI.py [options]

Classify amino acid residues into rotamer classes based on the Penultimate rotamer library 
(JS Richardson and DC Richardson (2000) "The Penultimate Rotamer Library"
Proteins: Structure Function and Genetics 40: 389-408.) 

    strudel_penultimateClassifier.py [options]
   
Superimpose and average amino acid residues maps using atom models as guide (requires rotamer classes generated by strudel_penultimateClassifier.py).

     strudel_mapAveraging.py [options]
     
Strudel score calculation. EM map-model validation based on strudel motif libraries.
Requires strudel map-motif libraries (http://ftp.ebi.ac.uk/pub/databases/emdb_vault/strudel_libs/).
The results can be visualised using the Strudel Score plugin for ChimeraX (https://cxtoolshed.rbvi.ucsf.edu/apps/chimeraxstrudelscore).


    strudel_mapMotifValidation.py [options]
    
# License

threed_strudel is free and open source software released under the terms of the Apache License, Version 2.0. 
Source code is copyright EMBL-European Bioinformatics Institute (EMBL-EBI) 2017.
    
